# Generated by roxygen2: do not edit by hand

S3method("[",pep)
S3method(plot,pep)
S3method(plot,pep_completeness)
S3method(plot,pep_coverage)
S3method(plot,pep_outliers)
S3method(plot,pep_quality)
S3method(plot,pheno_anomaly)
S3method(plot,pheno_combined)
S3method(plot,pheno_gradient)
S3method(plot,pheno_normals)
S3method(plot,pheno_pls)
S3method(plot,pheno_synchrony)
S3method(plot,pheno_turning)
S3method(plot,second_events)
S3method(print,pep)
S3method(print,pep_completeness)
S3method(print,pep_coverage)
S3method(print,pep_outliers)
S3method(print,pep_quality)
S3method(print,phase_check)
S3method(print,phase_check_multi)
S3method(print,pheno_anomaly)
S3method(print,pheno_combined)
S3method(print,pheno_gradient)
S3method(print,pheno_normals)
S3method(print,pheno_pls)
S3method(print,pheno_synchrony)
S3method(print,pheno_turning)
S3method(print,second_events)
S3method(summary,pep)
S3method(summary,pep_completeness)
S3method(summary,pep_outliers)
S3method(summary,pep_quality)
S3method(summary,pheno_anomaly)
S3method(summary,pheno_normals)
S3method(summary,pheno_pls)
S3method(summary,pheno_synchrony)
S3method(summary,second_events)
export(add_country)
export(add_daylength)
export(as.pep)
export(bbch_description)
export(calc_daylength)
export(calc_max_daylength)
export(calc_thermal_sum)
export(calc_thermal_units)
export(get_phenology_doys)
export(is.pep)
export(kendall_tau)
export(mann_kendall_z)
export(new_pep)
export(pep725_demo)
export(pep_cache_clear)
export(pep_cache_info)
export(pep_check_connectivity)
export(pep_check_phases)
export(pep_check_phases_multi)
export(pep_completeness)
export(pep_coverage)
export(pep_download)
export(pep_flag_outliers)
export(pep_import)
export(pep_outliers_leaflet)
export(pep_plot_outliers)
export(pep_quality)
export(pep_second_events)
export(pep_simulate)
export(pheno_anomaly)
export(pheno_combine)
export(pheno_gradient)
export(pheno_leaflet)
export(pheno_map)
export(pheno_normals)
export(pheno_plot)
export(pheno_plot_hh)
export(pheno_plot_timeseries)
export(pheno_pls)
export(pheno_regional)
export(pheno_regional_hh)
export(pheno_synchrony)
export(pheno_trend_turning)
export(plot_phenology_trends)
export(select_phase)
export(subspecies_report)
export(summarize_subspecies_availability)
import(ggplot2)
import(methods)
importFrom(data.table,.N)
importFrom(data.table,.SD)
importFrom(data.table,as.data.table)
importFrom(data.table,copy)
importFrom(data.table,fifelse)
importFrom(data.table,fread)
importFrom(data.table,melt)
importFrom(data.table,rbindlist)
importFrom(data.table,setDT)
importFrom(data.table,setcolorder)
importFrom(data.table,setnames)
importFrom(data.table,setorderv)
importFrom(data.table,uniqueN)
importFrom(dplyr,"%>%")
importFrom(dplyr,across)
importFrom(dplyr,any_of)
importFrom(dplyr,arrange)
importFrom(dplyr,coalesce)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,n_distinct)
importFrom(dplyr,recode)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_quickmap)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,stat_summary)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_minimal)
importFrom(patchwork,wrap_plots)
importFrom(purrr,map)
importFrom(rnaturalearth,ne_countries)
importFrom(robustbase,lmrob)
importFrom(sf,"st_agr<-")
importFrom(sf,st_agr)
importFrom(sf,st_as_sf)
importFrom(sf,st_bbox)
importFrom(sf,st_join)
importFrom(sf,st_make_valid)
importFrom(sf,st_transform)
importFrom(stats,"contrasts<-")
importFrom(stats,IQR)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,contr.sum)
importFrom(stats,lm)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,weighted.mean)
importFrom(tibble,tibble)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unite)
importFrom(utils,data)
importFrom(utils,globalVariables)
importFrom(utils,head)
importFrom(utils,setTxtProgressBar)
importFrom(utils,tail)
importFrom(utils,txtProgressBar)
