% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pheno_combine.R
\name{fit_lad}
\alias{fit_lad}
\title{Fit LAD (Robust) Model}
\usage{
fit_lad(dt)
}
\description{
Fit LAD (Robust) Model
}
\keyword{internal}
