% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pep_download.R
\name{pep_cache_info}
\alias{pep_cache_info}
\title{Get Cache Information}
\usage{
pep_cache_info()
}
\value{
A list with cache information, or NULL if no cache exists.
}
\description{
Returns information about the cached PEP data.
}
\examples{
\donttest{
# Check cache status
pep_cache_info()
}

}
\author{
Matthias Templ
}
