% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pep_class.R
\name{bbch_description}
\alias{bbch_description}
\title{Get BBCH Phase Description}
\usage{
bbch_description(codes, na.rm = TRUE, sort = TRUE)
}
\arguments{
\item{codes}{Integer vector of BBCH codes.}

\item{na.rm}{Logical. If \code{TRUE} (default), removes NA codes and codes
without a known description from the output.}

\item{sort}{Logical. If \code{TRUE} (default), sorts the output by phase code.}
}
\value{
A data.frame with columns \code{phase_id} and \code{description},
ordered by phase code (if \code{sort = TRUE}).
}
\description{
Returns human-readable descriptions for BBCH phenological codes.
}
\examples{
bbch_description(c(60, 65, 100))
bbch_description(c(100, 60, 65, NA), na.rm = TRUE, sort = TRUE)

}
\author{
Matthias Templ
}
