% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pep_class.R
\name{print.pep}
\alias{print.pep}
\title{Print Method for PEP725 Data}
\usage{
\method{print}{pep}(x, n = 5, ...)
}
\arguments{
\item{x}{A \code{pep} object.}

\item{n}{Number of rows to display (default 5).}

\item{...}{Additional arguments passed to print.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Displays a concise summary of the PEP725 phenological dataset.
}
\examples{
\donttest{
pep <- pep_download()
print(pep)
}

}
\author{
Matthias Templ
}
