% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pheno_combine.R
\name{fit_mixed}
\alias{fit_mixed}
\title{Fit Mixed-Effects Model}
\usage{
fit_mixed(dt)
}
\description{
Fit Mixed-Effects Model
}
\keyword{internal}
