% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pheno_pls.R
\name{summary.pheno_pls}
\alias{summary.pheno_pls}
\title{Summary Method for PLS Phenology Results}
\usage{
\method{summary}{pheno_pls}(object, vip_threshold = 0.8, ...)
}
\arguments{
\item{object}{A \code{pheno_pls} object}

\item{vip_threshold}{Numeric. VIP threshold for identifying important
periods. Default 0.8.}

\item{...}{Additional arguments (unused)}
}
\value{
Invisibly returns a summary data.frame
}
\description{
Summary Method for PLS Phenology Results
}
