% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pheno_pls.R
\name{plot.pheno_pls}
\alias{plot.pheno_pls}
\title{Plot Method for PLS Phenology Results}
\usage{
\method{plot}{pheno_pls}(x, type = c("vip", "coef", "both"), vip_threshold = 0.8, ...)
}
\arguments{
\item{x}{A \code{pheno_pls} object}

\item{type}{Character. Plot type: "vip" for VIP scores (default),
"coef" for coefficients, "both" for combined plot.}

\item{vip_threshold}{Numeric. Threshold line for VIP plot. Default 0.8.}

\item{...}{Additional arguments passed to plotting functions}
}
\value{
A ggplot object (invisibly)
}
\description{
Plot Method for PLS Phenology Results
}
