% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pep_completeness.R
\name{summary.pep_completeness}
\alias{summary.pep_completeness}
\title{Summary Method for Completeness Assessment}
\usage{
\method{summary}{pep_completeness}(object, ...)
}
\arguments{
\item{object}{A \code{pep_completeness} object}

\item{...}{Additional arguments (unused)}
}
\value{
Invisibly returns a summary list
}
\description{
Summary Method for Completeness Assessment
}
\author{
Matthias Templ
}
